import * as React from "react";

import { CourseSearchProvider, useCourseSearch } from "openfing-core/lib/hooks/useCourseSearch";

import { LayoutContext } from "../../layout/Layout";
import { NavigationComponentProps } from "../../navigation/Navigator";
import { styles } from "./Courses.styles";
import { useContext } from "react";
import { useDocumentTitle } from "../../components/useDocumentTitle";
import { useFetchCourses } from "openfing-core/lib/hooks";
import { useRootStore } from "openfing-core/lib/hooks/useRootStore";

export const Courses: React.FunctionComponent<NavigationComponentProps> = () => {
	const [searchValue, setSearchValue] = React.useState("");
	useDocumentTitle("Cursos - OpenFING");

	const setLayoutOptions = useContext(LayoutContext);
	useFetchCourses({ autoFetch: true });

	const { courseStore } = useRootStore();

	React.useEffect(() => {
		setLayoutOptions({
			header: {
				title: <styles.SearchInput placeholder="Buscar" onChangeText={setSearchValue} />,
			},
		});
	}, [setLayoutOptions]);

	return (
		<CourseSearchProvider courses={courseStore.courseList} searchValue={searchValue} onValueChange={setSearchValue}>
			<styles.Wrapper>
				<styles.CourseList />

				<styles.CreativeCommons />
			</styles.Wrapper>
		</CourseSearchProvider>
	);
};
